﻿using System.Collections.ObjectModel;
using System.Windows;
using ThinkGeo.MapSuite;
using ThinkGeo.MapSuite.Layers;
using ThinkGeo.MapSuite.Shapes;
using ThinkGeo.MapSuite.Styles;
using ThinkGeo.MapSuite.Wpf;

namespace _9488
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
        }

        private void map_Loaded(object sender, RoutedEventArgs e)
        {
            map.MapUnit = GeographyUnit.DecimalDegree;

            InMemoryFeatureLayer imf = new InMemoryFeatureLayer();
            imf.ZoomLevelSet.ZoomLevel01.DefaultLineStyle = LineStyles.LocalRoad4;
            imf.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.Country1;
            imf.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            LayerOverlay layerOverlay = new LayerOverlay();
            layerOverlay.Layers.Add("testLayer", imf);
            map.Overlays.Add(layerOverlay);

            PolygonShape poly = new PolygonShape();
            poly.OuterRing.Vertices.Add(new Vertex(0, 0));
            poly.OuterRing.Vertices.Add(new Vertex(5, 5));
            poly.OuterRing.Vertices.Add(new Vertex(10, 0));
            poly.OuterRing.Vertices.Add(new Vertex(-10, -10));
            poly.OuterRing.Vertices.Add(new Vertex(0, 0));

            Feature polyFeature = new Feature(poly);
            polyFeature.Id = "Poly";
            polyFeature.ColumnValues.Add("col1", "test1");
            polyFeature.ColumnValues.Add("col2", "test2");

            imf.InternalFeatures.Add(polyFeature.Id, polyFeature);

            foreach (Feature feature in imf.InternalFeatures)
            {
                map.EditOverlay.EditShapesLayer.InternalFeatures.Add(feature.Id, feature);
            }


            map.EditOverlay.CalculateAllControlPoints();

            map.EditOverlay.FeatureEdited += EditOverlay_FeatureEdited;

            imf.Open();
            map.CurrentExtent = imf.GetBoundingBox();
            map.Refresh();
        }

        private void EditOverlay_FeatureEdited(object sender, FeatureEditedEditInteractiveOverlayEventArgs e)
        {
            //Clear any features in the DrawingOverlay
            foreach (InMemoryFeatureLayer layer in (map.Overlays[0] as LayerOverlay).Layers)
            {
                layer.InternalFeatures.Clear();
            }

            //Add each feature in the EditOverlay to the appropriate layer in DrawingOverlay based on its shape
            foreach (Feature feature in map.EditOverlay.EditShapesLayer.InternalFeatures)
            {
                InMemoryFeatureLayer imf = (map.Overlays[0] as LayerOverlay).Layers[0] as InMemoryFeatureLayer;

                imf.InternalFeatures.Add(feature.Id, feature);
            }

            map.EditOverlay.EditShapesLayer.Clear(); //remove all the features in the edit overlay            
            map.EditOverlay.CalculateAllControlPoints();
            map.Refresh();
        }

        private void Button_Click(object sender, RoutedEventArgs e)
        {
            Feature feature = (map.FindFeatureLayer("testLayer") as InMemoryFeatureLayer).InternalFeatures["Poly"];
            PolygonShape poly = new PolygonShape();
            poly.OuterRing.Vertices.Add(new Vertex(0, 0));
            poly.OuterRing.Vertices.Add(new Vertex(5, 5));
            poly.OuterRing.Vertices.Add(new Vertex(10, 0));
            poly.OuterRing.Vertices.Add(new Vertex(11, 11));
            poly.OuterRing.Vertices.Add(new Vertex(0, 0));

            feature = new Feature(poly);
            map.Refresh();
        }
    }
}